@@ -662,10 +662,9 @@ display_setting_screen_changed (GtkWidget *widget,
 
 static gboolean
 display_setting_identity_popup_draw (GtkWidget      *popup,
-                                       cairo_t *c,
-                                       GtkBuilder     *builder)
+                                     cairo_t *cr,
+                                     GtkBuilder     *builder)
 {
-    cairo_t         *cr = gdk_cairo_create (gtk_widget_get_window(popup));
     cairo_pattern_t *vertical_gradient, *innerstroke_gradient, *selected_gradient, *selected_innerstroke_gradient;
     gint             radius;
     gboolean         selected = (g_hash_table_lookup (display_popups, GINT_TO_POINTER (active_output)) == popup);
@@ -769,7 +768,6 @@ display_setting_identity_popup_draw (GtkWidget      *popup,
         cairo_close_path (cr);
     }
 
-    cairo_destroy (cr);
     cairo_pattern_destroy (vertical_gradient);
     cairo_pattern_destroy (innerstroke_gradient);
     cairo_pattern_destroy (selected_gradient);
@@ -822,8 +820,10 @@ display_setting_identity_display (gint display_id)
         {
             screen_pos_x = 0;
             screen_pos_y = 0;
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
             screen_width = gdk_screen_width ();
             screen_height = gdk_screen_height ();
+G_GNUC_END_IGNORE_DEPRECATIONS
         }
 
         name_label = g_markup_printf_escaped ("<span foreground='%s'><big><b>%s %s</b></big></span>",
@@ -2239,6 +2239,9 @@ on_output_event (FooScrollArea      *area,
      * on_canvas_event() for where we reset the cursor to the default if it
      * exits the outputs' area.
      */
+    if (event->type == FOO_MOTION_OUTSIDE)
+        return;
+
     if (!get_mirrored_configuration() && get_n_connected() > 1)
         set_cursor (GTK_WIDGET (area), GDK_FLEUR);
 
@@ -2882,6 +2885,7 @@ display_settings_show_minimal_dialog (GdkDisplay *display)
     GError     *error = NULL;
     gboolean    found = FALSE;
     RRMode      mode;
+    GtkApplication *app;
 
     builder = gtk_builder_new ();
 
@@ -2968,6 +2972,24 @@ display_settings_show_minimal_dialog (GdkDisplay *display)
             gtk_widget_set_sensitive (GTK_WIDGET (only_display2), FALSE);
         }
 
+        /* Initialize application to ensure single instance */
+        app = gtk_application_new ("org.xfce.display.settings", 0);
+
+        g_application_register (G_APPLICATION (app), NULL, &error);
+        if (error != NULL)
+          {
+            g_warning ("Unable to register GApplication: %s", error->message);
+            g_error_free (error);
+            error = NULL;
+          }
+
+        if (g_application_get_is_remote (G_APPLICATION (app)))
+          {
+            g_application_activate (G_APPLICATION (app));
+            g_object_unref (app);
+            return;
+          }
+
         g_signal_connect (only_display1, "toggled", G_CALLBACK (display_settings_minimal_only_display1_toggled),
                           builder);
         g_signal_connect (mirror_displays, "toggled", G_CALLBACK (display_settings_minimal_mirror_displays_toggled),
@@ -2979,6 +3001,8 @@ display_settings_show_minimal_dialog (GdkDisplay *display)
         g_signal_connect (advanced, "clicked", G_CALLBACK (display_settings_minimal_advanced_clicked),
                           builder);
 
+        g_signal_connect_swapped (app, "activate", G_CALLBACK (gtk_window_present), dialog);
+
         /* Show the minimal dialog and start the main loop */
         gtk_window_present (GTK_WINDOW (dialog));
         gtk_main ();
