@@ -29,6 +29,7 @@
 #endif
 
 #include <gtk/gtk.h>
+#include <gtk/gtkx.h>
 
 #include <xfconf/xfconf.h>
 #include <libxfce4util/libxfce4util.h>
@@ -59,7 +60,7 @@ save_window_size (GtkWidget *dialog, XfceSettingsEditorBox *settings_editor)
 
 	g_object_get (G_OBJECT(settings_editor), "paned-pos", &paned_pos, NULL);
 
-	state = gdk_window_get_state ((dialog)->window);
+	state = gdk_window_get_state (gtk_widget_get_window(dialog));
 
 	if ((state & (GDK_WINDOW_STATE_MAXIMIZED | GDK_WINDOW_STATE_FULLSCREEN)) == 0)
 	{
@@ -134,7 +135,7 @@ main(gint argc, gchar **argv)
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2018");
+        g_print ("%s\n", "Copyright (c) 2008-2011");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
