@@ -506,9 +506,7 @@ xfce_displays_helper_screen_on_event (GdkXEvent *xevent,
                         {
                             crtc->mode = output->preferred_mode;
                             crtc->rotation = RR_Rotate_0;
-                            if ((crtc->x > gdk_screen_width() + 1) || (crtc->y > gdk_screen_height() + 1)) {
-                                crtc->x = crtc->y = 0;
-                            } /* else - leave values from last time we saw the monitor */
+                            crtc->x = crtc->y = 0;
                             /* set width and height */
                             for (j = 0; j < helper->resources->nmode; ++j)
                             {
@@ -560,6 +558,7 @@ xfce_displays_helper_set_screen_size (XfceDisplaysHelper *helper)
         return;
     }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     xfsettings_dbg (XFSD_DEBUG_DISPLAYS, "min_h = %d, min_w = %d, max_h = %d, max_w = %d, "
                     "prev_h = %d, prev_w = %d, prev_hmm = %d, prev_wmm = %d, h = %d, w = %d, "
                     "hmm = %d, wmm = %d.", min_height, min_width, max_height, max_width,
@@ -580,6 +579,7 @@ xfce_displays_helper_set_screen_size (XfceDisplaysHelper *helper)
         XRRSetScreenSize (helper->xdisplay, GDK_WINDOW_XID (helper->root_window),
                           helper->width, helper->height, helper->mm_width, helper->mm_height);
     }
+G_GNUC_END_IGNORE_DEPRECATIONS
 }
 
 
@@ -859,13 +859,15 @@ xfce_displays_helper_list_outputs (XfceDisplaysHelper *helper)
                 if (helper->resources->modes[m].id != output->info->modes[l])
                     continue;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
                 if (l < output->info->npreferred)
                     dist = 0;
-                else if ((output->info->mm_height != 0) && (gdk_screen_height_mm () != 0))
+                else if (output->info->mm_height != 0)
                     dist = (1000 * gdk_screen_height () / gdk_screen_height_mm () -
                             1000 * helper->resources->modes[m].height / output->info->mm_height);
                 else
                     dist = gdk_screen_height () - helper->resources->modes[m].height;
+G_GNUC_END_IGNORE_DEPRECATIONS
 
                 dist = ABS (dist);
 
@@ -1404,9 +1406,7 @@ xfce_displays_helper_toggle_internal (gpointer           *power,
                 return;
             crtc->mode = lvds->preferred_mode;
             crtc->rotation = RR_Rotate_0;
-            if ((crtc->x > gdk_screen_width() + 1) || (crtc->y > gdk_screen_height() + 1)) {
-                crtc->x = crtc->y = 0;
-            } /* else - leave values from last time we saw the monitor */
+            crtc->x = crtc->y = 0;
             /* set width and height */
             for (m = 0; m < helper->resources->nmode; ++m)
             {
