@@ -47,7 +47,6 @@
 #include "pointers-defines.h"
 
 #define MAX_DENOMINATOR (100.00)
-#define XFCONF_TYPE_G_VALUE_ARRAY (dbus_g_type_get_collection ("GPtrArray", G_TYPE_VALUE))
 
 #ifdef XI_PROP_ENABLED
 #define DEVICE_ENABLED XI_PROP_ENABLED
@@ -219,7 +218,7 @@ xfce_pointers_is_enabled (Display *xdisplay,
     rc = XGetDeviceProperty (xdisplay, device, prop, 0, 1, False,
                              XA_INTEGER, &type, &format, &n_items,
                              &bytes_after, &data);
-    gdk_error_trap_pop ();
+    gdk_error_trap_pop_ignored ();
     if (rc == Success)
     {
         enabled = (gboolean) *data;
@@ -246,7 +245,7 @@ xfce_pointers_is_libinput (Display *xdisplay,
     rc = XGetDeviceProperty (xdisplay, device, prop, 0, 1, False,
                              XA_INTEGER, &type, &format, &n_items,
                              &bytes_after, &data);
-    gdk_error_trap_pop ();
+    gdk_error_trap_pop_ignored ();
     if (rc == Success)
     {
         XFree (data);
@@ -809,7 +808,7 @@ xfce_pointers_helper_change_property (XDeviceInfo  *device_info,
                 /* only 1 items to set */
                 val = value;
             }
-            else if (G_VALUE_TYPE (value) == XFCONF_TYPE_G_VALUE_ARRAY)
+            else if (G_VALUE_TYPE (value) == G_TYPE_PTR_ARRAY)
             {
                 array = g_value_get_boxed (value);
                 if (array->len != n_items)
